==> spip_3.2.11.orig.tar.xz: ecrire/lang/public_cs.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/public?lang_cible=cs
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// A
	'accueil_site' => 'Hlavní strana', # MODIF
	'articles' => 'Články',
	'articles_auteur' => 'Články tohoto autora',
	'articles_populaires' => 'Nejčtenější články',
	'articles_rubrique' => 'Články v této rubrice',
	'aucun_article' => 'Na této adrese není žádný článek',
	'aucun_auteur' => 'Na této adrese není žádný autor',
	'aucun_site' => 'Na této adrese není žádný odkaz',
	'aucune_breve' => 'Na této adrese není žádná novinka',
	'aucune_rubrique' => 'Na této adrese není žádná rubrika',
	'autres' => 'Ostatní',
	'autres_breves' => 'Další novinky',
	'autres_groupes_mots_clefs' => 'Další skupiny klíčových slov',
	'autres_sites' => 'Další odkazy',

	// B
	'bonjour' => 'Dobrý den',

	// C
	'commenter_site' => 'Komentář k tomuto odkazu',
	'copie_document_impossible' => 'Dokument není možné kopírovat',

	// D
	'date' => 'Datum',
	'dernier_ajout' => 'Poslední příspěvky',
	'dernieres_breves' => 'Poslední novinky',
	'derniers_articles' => 'Poslední články',
	'derniers_commentaires' => 'Poslední komentáře',
	'derniers_messages_forum' => 'Poslední příspěvky v diskusních fórech',

	// E
	'edition_mode_texte' => 'Textový režim',
	'en_reponse' => 'Odpověď na:',
	'en_resume' => 'Shrnutí',
	'envoyer_message' => 'Odeslat zprávu',
	'espace_prive' => 'Vstup pro autory',

	// F
	'formats_acceptes' => 'Povolené formáty: @formats@.',

	// H
	'hierarchie_site' => 'Struktura stránek',

	// J
	'jours' => 'dnů',

	// L
	'lien_connecter' => 'Přihlášení',

	// M
	'meme_auteur' => 'Od stejného autora',
	'meme_rubrique' => 'Ve stejné rubrice',
	'memes_auteurs' => 'Od stejných autorů',
	'message' => 'Zpráva',
	'messages_forum' => 'Zprávy v diskusním fóru', # MODIF
	'messages_recents' => 'Poslední zprávy v diskusních fórech',
	'mots_clefs' => 'Klíčová slova',
	'mots_clefs_meme_groupe' => 'Klíčová slova ve stejné skupině',

	// N
	'navigation' => 'Navigace',
	'nom' => 'Jméno',
	'nouveautes' => 'Co je nového',
	'nouveautes_web' => 'Novinky na webu',
	'nouveaux_articles' => 'Nové články',
	'nouvelles_breves' => 'Nové novinky',

	// P
	'page_precedente' => 'předchozí strana',
	'page_suivante' => 'další strana',
	'par_auteur' => 'napsal(a)',
	'participer_site' => 'Můžete se aktivně zapojit a napsat nějaký článek pro tento web - zaregistrujte se níže. Okamžitě obdržíte e-mail s přístupovými kódy do části pro autory.',
	'plan_site' => 'Mapa stránek',
	'popularite' => 'Popularita',
	'poster_message' => 'Napsat zprávu',
	'proposer_site' => 'Můžete navrhnout odkaz, který má být zařazen do této rubriky:',

	// R
	'repondre_article' => 'Reagovat na tento článek',
	'repondre_breve' => 'Reagovat na tuto novinku ',
	'resultats_recherche' => 'Výsledky hledání',
	'retour_debut_forums' => 'Zpět na začátek diskusních fór',
	'rubrique' => 'Rubrika',
	'rubriques' => 'Rubriky',

	// S
	'signatures_petition' => 'Podpisy',
	'site_realise_avec_spip' => 'Stránky vytvořeny pomocí SPIP',
	'sites_web' => 'Odkazy',
	'sous_rubriques' => 'Podrubriky',
	'spam' => 'Spam',
	'suite' => 'pokračování',
	'sur_web' => 'Na webu',
	'syndiquer_rubrique' => 'Zahrnout tuto rubriku',
	'syndiquer_site' => 'Zahrnout celý web',

	// T
	'texte_lettre_information' => 'Zde je zpravodaj tohoto webu',
	'texte_lettre_information_2' => 'Tento soupis sumarizuje články a novinky publikované od ', # MODIF

	// V
	'ver_imprimer' => 'Verze pro tisk',
	'voir_en_ligne' => 'Podívejte se online',
	'voir_squelette' => 'Zobrazit šablonu této stránky'
);

==> spip_4.4.7+dfsg.orig.tar.xz: ecrire/lang/public_cs.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/public?lang_cible=cs
// ** ne pas modifier le fichier **

return [

	// A
	'accueil_site' => 'Hlavní strana', # MODIF
	'articles' => 'Články',
	'articles_auteur' => 'Články tohoto autora',
	'articles_populaires' => 'Nejčtenější články',
	'articles_rubrique' => 'Články v této rubrice',
	'aucun_article' => 'Na této adrese není žádný článek',
	'aucun_auteur' => 'Na této adrese není žádný autor',
	'aucun_site' => 'Na této adrese není žádný odkaz',
	'aucune_breve' => 'Na této adrese není žádná novinka',
	'aucune_rubrique' => 'Na této adrese není žádná rubrika',
	'autres' => 'Ostatní',
	'autres_breves' => 'Další novinky',
	'autres_groupes_mots_clefs' => 'Další skupiny klíčových slov',
	'autres_sites' => 'Další odkazy',

	// B
	'bonjour' => 'Dobrý den',

	// C
	'commenter_site' => 'Komentář k tomuto odkazu',
	'copie_document_impossible' => 'Dokument není možné kopírovat',

	// D
	'date' => 'Datum',
	'dernier_ajout' => 'Poslední příspěvky',
	'dernieres_breves' => 'Poslední novinky',
	'derniers_articles' => 'Poslední články',
	'derniers_commentaires' => 'Poslední komentáře',
	'derniers_messages_forum' => 'Poslední příspěvky v diskusních fórech',

	// E
	'edition_mode_texte' => 'Textový režim',
	'en_reponse' => 'Odpověď na:',
	'en_resume' => 'Shrnutí',
	'envoyer_message' => 'Odeslat zprávu',
	'espace_prive' => 'Vstup pro autory',

	// F
	'formats_acceptes' => 'Povolené formáty: @formats@.',

	// H
	'hierarchie_site' => 'Struktura stránek',

	// J
	'jours' => 'dnů',

	// L
	'lien_connecter' => 'Přihlášení',

	// M
	'meme_auteur' => 'Od stejného autora',
	'meme_rubrique' => 'Ve stejné rubrice',
	'memes_auteurs' => 'Od stejných autorů',
	'message' => 'Zpráva',
	'messages_forum' => 'Zprávy v diskusním fóru', # MODIF
	'messages_recents' => 'Poslední zprávy v diskusních fórech',
	'mots_clefs' => 'Klíčová slova',
	'mots_clefs_meme_groupe' => 'Klíčová slova ve stejné skupině',

	// N
	'navigation' => 'Navigace',
	'nom' => 'Jméno',
	'nouveautes' => 'Co je nového',
	'nouveautes_web' => 'Novinky na webu',
	'nouveaux_articles' => 'Nové články',
	'nouvelles_breves' => 'Nové novinky',

	// P
	'page_precedente' => 'předchozí strana',
	'page_suivante' => 'další strana',
	'par_auteur' => 'napsal(a)',
	'participer_site' => 'Můžete se aktivně zapojit a napsat nějaký článek pro tento web - zaregistrujte se níže. Okamžitě obdržíte e-mail s přístupovými kódy do části pro autory.',
	'plan_site' => 'Mapa stránek',
	'popularite' => 'Popularita',
	'poster_message' => 'Napsat zprávu',
	'proposer_site' => 'Můžete navrhnout odkaz, který má být zařazen do této rubriky:',

	// R
	'repondre_article' => 'Reagovat na tento článek',
	'repondre_breve' => 'Reagovat na tuto novinku ',
	'resultats_recherche' => 'Výsledky hledání',
	'retour_debut_forums' => 'Zpět na začátek diskusních fór',
	'rubrique' => 'Rubrika',
	'rubriques' => 'Rubriky',

	// S
	'signatures_petition' => 'Podpisy',
	'site_realise_avec_spip' => 'Stránky vytvořeny pomocí SPIP',
	'sites_web' => 'Odkazy',
	'sous_rubriques' => 'Podrubriky',
	'spam' => 'Spam',
	'suite' => 'pokračování',
	'sur_web' => 'Na webu',
	'syndiquer_rubrique' => 'Zahrnout tuto rubriku',
	'syndiquer_site' => 'Zahrnout celý web',

	// T
	'texte_lettre_information' => 'Zde je zpravodaj tohoto webu',
	'texte_lettre_information_2' => 'Tento soupis sumarizuje články a novinky publikované od ', # MODIF

	// V
	'ver_imprimer' => 'Verze pro tisk',
	'voir_en_ligne' => 'Podívejte se online',
	'voir_squelette' => 'Zobrazit šablonu této stránky',
];
